AdamW

Struct AdamW 

pub struct AdamW {
    pub learning_rate: f32,
    pub betas: (f32, f32),
    pub eps: f32,
    pub weight_decay: f32,
    pub amsgrad: bool,
    pub m: Vec<Tensor>,
    pub v: Vec<Tensor>,
    pub vm: Vec<Tensor>,
    pub t: usize,
}
Adaptive momentum estimation optimizer

Fields

learning_rate: f32

learning rate (default: 1e-3)

betas: (f32, f32)

coefficients used for computing running averages of gradient and its square (default: (0.9, 0.999))

eps: f32

term added to the denominator to improve numerical stability (default: 1e-8)

weight_decay: f32

weight decay (L2 penalty) (default: 0)

amsgrad: bool

whether to use the AMSGrad variant of this algorithm from the paper On the Convergence of Adam and Beyond (default: false)

m: Vec<Tensor>

m

v: Vec<Tensor>

v

vm: Vec<Tensor>

vm

t: usize

t

Implementations

Source

impl AdamW

pub fn update<'a>( &mut self, parameters: impl IntoIterator<Item = &'a mut Tensor>, gradients: impl IntoIterator<Item = Option<Tensor>>, )

Updates parameters with gradients. Number of parameters must be the same as number of gradients. Gradients can be None, those are simply skipped.